summaryrefslogtreecommitdiffstats
path: root/kolourpaint/kpview.h
diff options
context:
space:
mode:
Diffstat (limited to 'kolourpaint/kpview.h')
-rw-r--r--kolourpaint/kpview.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/kolourpaint/kpview.h b/kolourpaint/kpview.h
index 44674123..613cafd2 100644
--- a/kolourpaint/kpview.h
+++ b/kolourpaint/kpview.h
@@ -366,11 +366,11 @@ public:
* Removes the dirty region that has been queued for updating.
* Does not update the view.
*/
- void tqinvalidateQueuedArea ();
+ void invalidateQueuedArea ();
/**
* Updates the part of the view described by dirty region and then
* calls tqinvalidateQueuedArea(). Does nothing if @ref kpViewManager
* is set to queue updates.
*/
void updateQueuedArea ();
@@ -366,11 +366,11 @@ public:
/**
* Updates the part of the view described by dirty region and then
- * calls tqinvalidateQueuedArea(). Does nothing if @ref kpViewManager
+ * calls invalidateQueuedArea(). Does nothing if @ref kpViewManager
* is set to queue updates.
*/